@@ -351,6 +351,14 @@ int bfs_shadow_directory_stat(BFiles bfs, int no, const char **directory,
     return mf_area_directory_stat(bfs->commit_area, no, directory,
 				  used_bytes, max_bytes);
 }
+
+/* unimplemented functions not in use, but kept to ensure ABI */
+void bf_xclose() {}
+void bf_xopen() {}
+void bf_alloc() {}
+void bf_free() {}
+
+
 /*
  * Local variables:
  * c-basic-offset: 4
