@@ -39,7 +39,6 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include <idzebra/util.h>
 #include <rset.h>
 
-
 static RSFD r_open(RSET ct, int flag);
 static void r_close(RSFD rfd);
 static void r_delete(RSET ct);
@@ -62,15 +61,11 @@ static const struct rset_control control =
     rset_no_write,
 };
 
-#define STARTTAG 0
-#define HIT 1
-#define STOPTAG 2
-#define ATTRTAG 3
-
 struct rset_between_info {
     TERMID startterm; /* pseudo terms for detecting which one we read from */
     TERMID stopterm;
     TERMID attrterm;
+    TERMID *hit2_terms;
 };
 
 struct rset_between_rfd {
@@ -82,6 +77,8 @@ struct rset_between_rfd {
     int attrbufok; /* we have seen the first attr tag, can compare */
     int depth; /* number of start-tags without end-tags */
     int attrdepth; /* on what depth the attr matched */
+    int match_1;
+    int match_2;
     zint hits;
 };
 
@@ -102,42 +99,54 @@ static void checkterm(RSET rs, char *tag, NMEM nmem)
 
 
 RSET rset_create_between(NMEM nmem, struct rset_key_control *kcontrol,
-                         int scope,
-                         RSET rset_l, RSET rset_m, RSET rset_r, RSET rset_attr)
+                         int scope, RSET rset_l, RSET rset_m1, RSET rset_m2,
+                         RSET rset_r, RSET rset_attr)
 {
     RSET rnew = rset_create_base(&control, nmem, kcontrol, scope, 0, 0, 0);
-    struct rset_between_info *info=
+    struct rset_between_info *info =
         (struct rset_between_info *) nmem_malloc(rnew->nmem,sizeof(*info));
-    RSET rsetarray[4];
-    int n = 4;
+    RSET rsetarray[5];
+    int n = 0;
 
     if (!log_level_initialized)
     {
         log_level = yaz_log_module_level("rsbetween");
         log_level_initialized = 1;
     }
-    rsetarray[STARTTAG] = rset_l;
-    rsetarray[HIT] = rset_m;
-    rsetarray[STOPTAG] = rset_r;
-    rsetarray[ATTRTAG] = rset_attr;
+    rsetarray[n++] = rset_l;
+    checkterm(rset_l, "", nmem);
+    info->startterm = rset_l->term;
 
-    /* make sure we have decent terms for all rsets. Create dummies if needed*/
-    checkterm(rsetarray[STARTTAG], "(start)", nmem);
-    checkterm(rsetarray[STOPTAG], "(start)", nmem);
-    info->startterm = rsetarray[STARTTAG]->term;
-    info->stopterm = rsetarray[STOPTAG]->term;
+    rsetarray[n++] = rset_r;
+    checkterm(rset_r, "", nmem);
+    info->stopterm = rset_r->term;
+
+    rsetarray[n++] = rset_m1;
+    if (rset_m2)
+    {
+        rsetarray[n++] = rset_m2;
+        /* hard to work do determine whether we get results from
+           rset_m2 or rset_m1 */
+        info->hit2_terms = (TERMID*)
+            nmem_malloc(nmem, (2 + rset_m2->no_children) * sizeof(TERMID));
+        int i;
+        for (i = 0; i < rset_m2->no_children; i++) /* sub terms */
+            info->hit2_terms[i] = rset_m2->children[i]->term;
+        if (rset_m2->term) /* immediate term */
+            info->hit2_terms[i++] = rset_m2->term;
+        info->hit2_terms[i] = 0;
+    }
+    else
+        info->hit2_terms = NULL;
 
     if (rset_attr)
     {
-        checkterm(rsetarray[ATTRTAG], "(start)", nmem);
-        info->attrterm = rsetarray[ATTRTAG]->term;
-        n = 4;
+        rsetarray[n++] = rset_attr;
+        checkterm(rset_attr, "(attr)", nmem);
+        info->attrterm = rset_attr->term;
     }
     else
-    {
         info->attrterm = NULL;
-        n = 3;
-    }
     rnew->no_children = 1;
     rnew->children = nmem_malloc(rnew->nmem, sizeof(RSET *));
     rnew->children[0] = rset_create_and(nmem, kcontrol,
@@ -164,9 +173,9 @@ static RSFD r_open(RSET ct, int flag)
     }
     rfd = rfd_create_base(ct);
     if (rfd->priv)
-        p=(struct rset_between_rfd *)rfd->priv;
+        p = (struct rset_between_rfd *) rfd->priv;
     else {
-        p = (struct rset_between_rfd *) nmem_malloc(ct->nmem, (sizeof(*p)));
+        p = (struct rset_between_rfd *) nmem_malloc(ct->nmem, sizeof(*p));
         rfd->priv = p;
         p->recbuf = nmem_malloc(ct->nmem, ct->keycontrol->key_size);
         p->startbuf = nmem_malloc(ct->nmem, ct->keycontrol->key_size);
@@ -184,15 +193,15 @@ static RSFD r_open(RSET ct, int flag)
 
 static void r_close(RSFD rfd)
 {
-    struct rset_between_rfd *p=(struct rset_between_rfd *)rfd->priv;
-    yaz_log(log_level,"close rfd=%p", rfd);
+    struct rset_between_rfd *p = (struct rset_between_rfd *) rfd->priv;
+    yaz_log(log_level, "close rfd=%p", rfd);
     rset_close(p->andrfd);
 }
 
 static int r_forward(RSFD rfd, void *buf,
                      TERMID *term, const void *untilbuf)
 {
-    struct rset_between_rfd *p=(struct rset_between_rfd *)rfd->priv;
+    struct rset_between_rfd *p = (struct rset_between_rfd *) rfd->priv;
     int rc;
     yaz_log(log_level, "forwarding ");
     rc = rset_forward(p->andrfd,buf,term,untilbuf);
@@ -201,7 +210,7 @@ static int r_forward(RSFD rfd, void *buf,
 
 static void checkattr(RSFD rfd)
 {
-    struct rset_between_info *info =(struct rset_between_info *)
+    struct rset_between_info *info = (struct rset_between_info *)
 	rfd->rset->priv;
     struct rset_between_rfd *p = (struct rset_between_rfd *)rfd->priv;
     const struct rset_key_control *kctrl = rfd->rset->keycontrol;
@@ -210,16 +219,17 @@ static void checkattr(RSFD rfd)
         return; /* already found one */
     if (!info->attrterm)
     {
-        p->attrdepth=-1; /* matches always */
+        p->attrdepth = -1; /* matches always */
         return;
     }
     if ( p->startbufok && p->attrbufok )
     { /* have buffers to compare */
-        cmp=(kctrl->cmp)(p->startbuf,p->attrbuf);
-        if (0==cmp) /* and the keys match */
+        cmp = (kctrl->cmp)(p->startbuf, p->attrbuf);
+        if (0 == cmp) /* and the keys match */
         {
             p->attrdepth = p->depth;
-            yaz_log(log_level, "found attribute match at depth %d",p->attrdepth);
+            yaz_log(log_level, "found attribute match at depth %d",
+                    p->attrdepth);
         }
     }
 }
@@ -237,9 +247,9 @@ static int r_read(RSFD rfd, void *buf, TERMID *term)
         term = &dummyterm;
     while (rset_read(p->andrfd, buf, term))
     {
-        yaz_log(log_level,"read loop term=%p d=%d ad=%d",
+        yaz_log(log_level, "read loop term=%p d=%d ad=%d",
                 *term, p->depth, p->attrdepth);
-        if (p->hits<0)
+        if (p->hits < 0)
         {/* first time? */
             memcpy(p->recbuf, buf, kctrl->key_size);
             p->hits = 0;
@@ -250,17 +260,18 @@ static int r_read(RSFD rfd, void *buf, TERMID *term)
             yaz_log(log_level, "cmp=%d", cmp);
         }
 
-        if (cmp>=rfd->rset->scope)
+        if (cmp >= rfd->rset->scope)
         {
             yaz_log(log_level, "new record");
             p->depth = 0;
             p->attrdepth = 0;
+            p->match_1 = p->match_2 = 0;
             memcpy(p->recbuf, buf, kctrl->key_size);
         }
 
         if (*term)
             yaz_log(log_level, "  term: '%s'", (*term)->name);
-        if (*term==info->startterm)
+        if (*term == info->startterm)
         {
             p->depth++;
             yaz_log(log_level, "read start tag. d=%d", p->depth);
@@ -268,17 +279,19 @@ static int r_read(RSFD rfd, void *buf, TERMID *term)
             p->startbufok = 1;
             checkattr(rfd); /* in case we already saw the attr here */
         }
-        else if (*term==info->stopterm)
+        else if (*term == info->stopterm)
         {
             if (p->depth == p->attrdepth)
                 p->attrdepth = 0; /* ending the tag with attr match */
             p->depth--;
-            yaz_log(log_level,"read end tag. d=%d ad=%d", p->depth,
+            if (p->depth == 0)
+                p->match_1 = p->match_2 = 0;
+            yaz_log(log_level, "read end tag. d=%d ad=%d", p->depth,
 		    p->attrdepth);
         }
-        else if (*term==info->attrterm)
+        else if (*term == info->attrterm)
         {
-            yaz_log(log_level,"read attr");
+            yaz_log(log_level, "read attr");
             memcpy(p->attrbuf, buf, kctrl->key_size);
             p->attrbufok = 1;
             checkattr(rfd); /* in case the start tag came first */
@@ -287,23 +300,37 @@ static int r_read(RSFD rfd, void *buf, TERMID *term)
         { /* mut be a real hit */
             if (p->depth && p->attrdepth)
             {
-                p->hits++;
-                yaz_log(log_level,"got a hit h="ZINT_FORMAT" d=%d ad=%d",
-                        p->hits, p->depth, p->attrdepth);
-                return 1; /* we have everything in place already! */
+                if (!info->hit2_terms)
+                    p->match_1 = p->match_2 = 1;
+                else
+                {
+                    int i;
+                    for (i = 0; info->hit2_terms[i]; i++)
+                        if (info->hit2_terms[i] == *term)
+                            break;
+                    if (info->hit2_terms[i])
+                        p->match_2 = 1;
+                    else
+                        p->match_1 = 1;
+                }
+                if (p->match_1 && p->match_2)
+                {
+                    p->hits++;
+                    yaz_log(log_level, "got a hit h="ZINT_FORMAT" d=%d ad=%d",
+                            p->hits, p->depth, p->attrdepth);
+                    return 1; /* we have everything in place already! */
+                }
             } else
                 yaz_log(log_level, "Ignoring hit. h="ZINT_FORMAT" d=%d ad=%d",
                         p->hits, p->depth, p->attrdepth);
         }
     } /* while read */
-
     return 0;
-
 }  /* r_read */
 
 static void r_pos(RSFD rfd, double *current, double *total)
 {
-    struct rset_between_rfd *p=(struct rset_between_rfd *)rfd->priv;
+    struct rset_between_rfd *p = (struct rset_between_rfd *) rfd->priv;
     rset_pos(p->andrfd, current, total);
     yaz_log(log_level, "pos: %0.1f/%0.1f ", *current, *total);
 }
